@@ -1,5 +1,5 @@
 /*
-    Copyright (c) 2004  Joey Schulze <joey@infodrom.org>
+    Copyright (c) 2004,7  Joey Schulze <joey@infodrom.org>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -25,7 +25,11 @@
 #include <sys/types.h>
 #include <pwd.h>
 #include <errno.h>
+#ifdef linux
 #include <paths.h>
+#else
+#define _PATH_MAILDIR "/var/spool/mail"
+#endif
 #include "mbox.h"
 #include "optdefs.h"
 
