@@ -90,6 +90,10 @@ int main(int argc, char *argv[])
 
     /* wait for the next incarnation */
     sleep (opt_interval);
+
+    /* Terminate if we lost out tty */
+    if (!isatty(1))
+      return 1;
   }
 
   /* Not reached */
